@@ -1,6 +1,6 @@
 /* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $RCSfile: builderSingle.cpp,v $
+ * $RCSfile$
  *
  * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
@@ -65,6 +65,9 @@ std::auto_ptr<XxDiffs> XxBuilderSingle::process( const XxBuffer& buffer )
    _curHunk = 0;
    createInsertLeftBlock( 1, buffer.getNbLines() );
 
+   // Set a succesful status.
+   _status = 0;
+
    std::auto_ptr<XxDiffs> ap( new XxDiffs( _lines, false, false ) );
    return ap;
 }
