@@ -1,6 +1,6 @@
 /* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $RCSfile: cmdline.h,v $
+ * $RCSfile$
  *
  * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
@@ -141,6 +141,7 @@ private:
    bool          _macNewlines;
    bool          _indicateInputProcessed;
    bool          _useTemporaryFiles;
+   bool          _promptForFiles;
 
    /*----- static data members -----*/
 
