@@ -1,6 +1,6 @@
 /* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $RCSfile: line.cpp,v $
+ * $RCSfile$
  *
  * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
@@ -116,7 +116,6 @@ XX_NAMESPACE_BEGIN
  * CLASS XxLine
  *============================================================================*/
 
-
 XxLine::Type XxLine::_ignoreConvertTables[4][ XxLine::NB_TYPES ] = {
    // No ignore.
    {                 XxLine::SAME,
@@ -188,6 +187,25 @@ XxLine::Type XxLine::_ignoreConvertTables[4][ XxLine::NB_TYPES ] = {
    }
 };
 
+int XxLine::_selectMasks[ XxLine::NB_TYPES ][ 3 ] = {
+   /* SAME        */ { 7, 7, 7 },
+   /* DIFF_1      */ { 1, 6, 6 },
+   /* DIFF_2      */ { 5, 2, 5 },
+   /* DIFF_3      */ { 3, 3, 4 },
+   /* DELETE_1    */ { 1, 6, 6 },
+   /* DELETE_2    */ { 5, 2, 5 },
+   /* DELETE_3    */ { 3, 3, 4 },
+   /* INSERT_1    */ { 1, 6, 6 },
+   /* INSERT_2    */ { 5, 2, 5 },
+   /* INSERT_3    */ { 3, 3, 4 },
+   /* DIFF_ALL    */ { 1, 2, 4 },
+   /* DIFFDEL_1   */ { 1, 2, 4 },
+   /* DIFFDEL_2   */ { 1, 2, 4 },
+   /* DIFFDEL_3   */ { 1, 2, 4 },
+   /* DIRECTORIES */ { 0, 0, 0 },
+};
+
+
 //------------------------------------------------------------------------------
 //
 XxLine::XxLine( 
