@@ -1,6 +1,6 @@
 /* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $RCSfile: line.h,v $
+ * $RCSfile$
  *
  * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
@@ -167,6 +167,11 @@ public:
    void setSelection( Selection selection );
    // </group>
 
+   // Return true if the given file is selected.  This takes care of checking
+   // for the line type, and if multiple sides end up being selected, it returns
+   // true for all of them.
+   bool isSelected( XxFno fno ) const;
+
    // Get/set ignore-display flag.
    // <group>
    bool getIgnoreDisplay() const;
@@ -275,6 +280,10 @@ private:
    // feature. This is not related to the ignore-display feature.
    static Type _ignoreConvertTables[ 4 ][ NB_TYPES ];
 
+   // Table that specifies which columns are selected when a specific selection
+   // is made.
+   static int _selectMasks[ XxLine::NB_TYPES ][ 3 ];
+
    /*----- data members -----*/
 
    XxFln       _lineNo[3];
