@@ -1,6 +1,6 @@
 /* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $RCSfile: markers.cpp,v $
+ * $RCSfile$
  *
  * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
@@ -299,7 +299,6 @@ QString XxMarkersFileDialog::getSaveFileName(
    XxMarkersFileDialog* dlg = new XxMarkersFileDialog(
       startWith, filter, parent, name, TRUE, threeWay
    );
-   CHECK_PTR( dlg );
    dlg->setCaption( QFileDialog::tr( "Save as" ) );
 
    QString result;
