@@ -1,6 +1,6 @@
 /* -*- c-file-style: "xxdiff" -*- */
 /******************************************************************************\
- * $RCSfile: resParser.h,v $
+ * $RCSfile$
  *
  * Copyright (C) 1999-2003  Martin Blais <blais@furius.ca>
  *
@@ -112,15 +112,9 @@ public:
    // Destructor.
    virtual ~XxResParser();
 
-private:
+   /*----- static data members -----*/
 
-   /*----- member functions -----*/
-
-   // Push/pop the parser stack.
-   // <group>
-   void push();
-   void pop();
-   // </group>
+   static const int BOOLKWD_BASE = 1000;
 
 };
 
